---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**What version of AgileRL are you using?**
**What operating system and processor architecture are you using?**

**What did you do?**
Steps to reproduce the behaviour:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**What did you expect to see?**
A clear and concise description of what you expected to happen.

**What did you see instead? Describe the bug.**
A clear and concise description of what the bug is.

**Additional context**
Add any other context about the problem here.
